// Reference : Probability and Statistics for Engineering and the Sciences, 4e
//              Jay L. Devore,1995, pp 22, 34
// Code :
// Written by Taesam Lee, Sep 2006, 
// Colorado State University, Department of Civil Engineering
//
// boxplot() produces a box and whisker points for the vector data. 
//The box has lines at the lower quartile, median, and upper quartile values. 
//The whiskers are lines extending from each end of the box to show the extent of the rest of the data. 
//Outliers are data with values beyond the ends of the whiskers. 
//Whiskers extend from the box out to the most extreme data value within 1.5*fs, 
//where fs is the range of two quartiel (lower and upper).
//
//		  +
//
//		  +			    outlier
//
//
//		  |
//		  |
//		  |
//		  |
//		 ---			upper quartile
//		|   |
//		|   |
//		|---|			median
//		|   |
//		|   |
//		 ---			lower quartile
//		  |
//		  |
//		  |
//		  |
//
//		  +				
//
// The number of outliers cannot exceed 100.

#ifndef BOXPLOT_H
#define BOXPLOT_H

#ifdef _CH_
#include <stdbool.h>
#endif
#include <chplot.h>


class CBoxplot
{
public://Functions
	CBoxplot();
	~CBoxplot();

	void estimateStat();
	bool Odd(int numD);
	double est_median(double dP[],int numD);
	double UpLow_end(double dP[],int numD,int b1);
	void SetData(double dPtr[],int numD);
	void sorting(double dP[],int numD);
	double maximum(double dP[],int numD);
	double minimum(double dP[],int numD);
	void increaseDArray(double x[],int &numD, double d1);
	void decreaseDArray(double x[],int &numD);

public:// Variables
	double median;
	double upperQ;
	double lowerQ;
	double fs;
	double end_up;
	double end_low;
	double *Outlier_up;
	double *Outlier_low;
	int numOL_up;
	int numOL_low;

private:// Variables
	int numdata;
	double* dptr_data;
};

extern int boxplot(CPlot *plot, double x[],int n,int numSep);

#ifdef _CH_
#pragma importf "boxplot.cpp"
#endif
#endif /* BOXPLOT_H */
